@@ -1,22 +1,34 @@
-# -*- coding: utf-8 -*-
-# Copyright (c) 2016-2017 Claudiu Popa <pcmanticore@gmail.com>
-# Copyright (c) 2016-2017 Ashley Whetter <ashley@awhetter.co.uk>
+# Copyright (c) 2016-2019, 2021 Ashley Whetter <ashley@awhetter.co.uk>
+# Copyright (c) 2016-2020 Claudiu Popa <pcmanticore@gmail.com>
 # Copyright (c) 2016 Yuri Bochkarev <baltazar.bz@gmail.com>
 # Copyright (c) 2016 Glenn Matthews <glenn@e-dad.net>
 # Copyright (c) 2016 Moises Lopez <moylop260@vauxoo.com>
-# Copyright (c) 2017 hippo91 <guillaume.peillex@gmail.com>
+# Copyright (c) 2017, 2020 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2017 Mitar <mitar.github@tnode.com>
+# Copyright (c) 2018, 2020 Anthony Sottile <asottile@umich.edu>
+# Copyright (c) 2018 Jim Robertson <jrobertson98atx@gmail.com>
+# Copyright (c) 2018 ssolanki <sushobhitsolanki@gmail.com>
+# Copyright (c) 2018 Mitchell T.H. Young <mitchelly@gmail.com>
+# Copyright (c) 2018 Adrian Chirieac <chirieacam@gmail.com>
+# Copyright (c) 2019 Hugo van Kemenade <hugovk@users.noreply.github.com>
+# Copyright (c) 2019 Danny Hermes <daniel.j.hermes@gmail.com>
+# Copyright (c) 2019 Zeb Nicholls <zebedee.nicholls@climate-energy-college.org>
+# Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
+# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
+# Copyright (c) 2021 allanc65 <95424144+allanc65@users.noreply.github.com>
+# Copyright (c) 2021 Konstantina Saketou <56515303+ksaketou@users.noreply.github.com>
+# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
+# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
 
 """Utility methods for docstring checking."""
 
-from __future__ import absolute_import, print_function
-
 import re
+from typing import List, Set, Tuple
 
 import astroid
+from astroid import nodes
 
 from pylint.checkers import utils
 
@@ -29,7 +41,7 @@ def space_indentation(s):
     :rtype: int
     :return: number of leading spaces
     """
-    return len(s) - len(s.lstrip(' '))
+    return len(s) - len(s.lstrip(" "))
 
 
 def get_setters_property_name(node):
@@ -44,9 +56,11 @@ def get_setters_property_name(node):
     """
     decorators = node.decorators.nodes if node.decorators else []
     for decorator in decorators:
-        if (isinstance(decorator, astroid.Attribute) and
-                decorator.attrname == "setter" and
-                isinstance(decorator.expr, astroid.Name)):
+        if (
+            isinstance(decorator, nodes.Attribute)
+            and decorator.attrname == "setter"
+            and isinstance(decorator.expr, nodes.Name)
+        ):
             return decorator.expr.name
     return None
 
@@ -55,9 +69,9 @@ def get_setters_property(node):
     """Get the property node for the given setter node.
 
     :param node: The node to get the property for.
-    :type node: astroid.FunctionDef
+    :type node: nodes.FunctionDef
 
-    :rtype: astroid.FunctionDef or None
+    :rtype: nodes.FunctionDef or None
     :returns: The node relating to the property of the given setter node,
         or None if one could not be found.
     """
@@ -90,7 +104,20 @@ def returns_something(return_node):
     if returns is None:
         return False
 
-    return not (isinstance(returns, astroid.Const) and returns.value is None)
+    return not (isinstance(returns, nodes.Const) and returns.value is None)
+
+
+def _get_raise_target(node):
+    if isinstance(node.exc, nodes.Call):
+        func = node.exc.func
+        if isinstance(func, (nodes.Name, nodes.Attribute)):
+            return utils.safe_infer(func)
+    return None
+
+
+def _split_multiple_exc_types(target: str) -> List[str]:
+    delimiters = r"(\s*,(?:\s*or\s)?\s*|\s+or\s+)"
+    return re.split(delimiters, target)
 
 
 def possible_exc_types(node):
@@ -103,51 +130,55 @@ def possible_exc_types(node):
 
 
     :param node: The raise node to find exception types for.
-    :type node: astroid.node_classes.NodeNG
+    :type node: nodes.NodeNG
 
     :returns: A list of exception types possibly raised by :param:`node`.
     :rtype: set(str)
     """
     excs = []
-    if isinstance(node.exc, astroid.Name):
+    if isinstance(node.exc, nodes.Name):
         inferred = utils.safe_infer(node.exc)
         if inferred:
             excs = [inferred.name]
-    elif (isinstance(node.exc, astroid.Call) and
-          isinstance(node.exc.func, astroid.Name)):
-        target = utils.safe_infer(node.exc.func)
-        if isinstance(target, astroid.ClassDef):
+    elif node.exc is None:
+        handler = node.parent
+        while handler and not isinstance(handler, nodes.ExceptHandler):
+            handler = handler.parent
+
+        if handler and handler.type:
+            inferred_excs = astroid.unpack_infer(handler.type)
+            excs = (exc.name for exc in inferred_excs if exc is not astroid.Uninferable)
+    else:
+        target = _get_raise_target(node)
+        if isinstance(target, nodes.ClassDef):
             excs = [target.name]
-        elif isinstance(target, astroid.FunctionDef):
-            for ret in target.nodes_of_class(astroid.Return):
+        elif isinstance(target, nodes.FunctionDef):
+            for ret in target.nodes_of_class(nodes.Return):
                 if ret.frame() != target:
                     # return from inner function - ignore it
                     continue
 
                 val = utils.safe_infer(ret.value)
-                if (val and isinstance(val, (astroid.Instance, astroid.ClassDef))
-                        and utils.inherit_from_std_ex(val)):
+                if (
+                    val
+                    and isinstance(val, (astroid.Instance, nodes.ClassDef))
+                    and utils.inherit_from_std_ex(val)
+                ):
                     excs.append(val.name)
-    elif node.exc is None:
-        handler = node.parent
-        while handler and not isinstance(handler, astroid.ExceptHandler):
-            handler = handler.parent
-
-        if handler and handler.type:
-            inferred_excs = astroid.unpack_infer(handler.type)
-            excs = (exc.name for exc in inferred_excs
-                    if exc is not astroid.Uninferable)
-
 
     try:
-        return set(exc for exc in excs if not utils.node_ignores_exception(node, exc))
+        return {exc for exc in excs if not utils.node_ignores_exception(node, exc)}
     except astroid.InferenceError:
         return set()
 
 
-def docstringify(docstring, default_type='default'):
-    for docstring_type in [SphinxDocstring, EpytextDocstring,
-                           GoogleDocstring, NumpyDocstring]:
+def docstringify(docstring, default_type="default"):
+    for docstring_type in (
+        SphinxDocstring,
+        EpytextDocstring,
+        GoogleDocstring,
+        NumpyDocstring,
+    ):
         instance = docstring_type(docstring)
         if instance.is_valid():
             return instance
@@ -156,12 +187,15 @@ def docstringify(docstring, default_type='default'):
     return docstring_type(docstring)
 
 
-class Docstring(object):
-    re_for_parameters_see = re.compile(r"""
+class Docstring:
+    re_for_parameters_see = re.compile(
+        r"""
         For\s+the\s+(other)?\s*parameters\s*,\s+see
-        """, re.X | re.S)
+        """,
+        re.X | re.S,
+    )
 
-    supports_yields = None
+    supports_yields: bool = False
     """True if the docstring supports a "yield" section.
 
     False if the docstring uses the returns section to document generators.
@@ -173,6 +207,9 @@ class Docstring(object):
         doc = doc or ""
         self.doc = doc.expandtabs()
 
+    def __repr__(self) -> str:
+        return f"<{self.__class__.__name__}:'''{self.doc}'''>"
+
     def is_valid(self):
         return False
 
@@ -208,19 +245,29 @@ class Docstring(object):
 
 
 class SphinxDocstring(Docstring):
-    re_type = r"[\w\.]+"
+    re_type = r"""
+        [~!.]?               # Optional link style prefix
+        \w(?:\w|\.[^\.])*    # Valid python name
+        """
 
-    re_simple_container_type = r"""
-        {type}                        # a container type
+    re_simple_container_type = fr"""
+        {re_type}                     # a container type
         [\(\[] [^\n\s]+ [\)\]]        # with the contents of the container
-    """.format(type=re_type)
+    """
 
-    re_xref = r"""
+    re_multiple_simple_type = r"""
+        (?:{container_type}|{type})
+        (?:(?:\s+(?:of|or)\s+|\s*,\s*)(?:{container_type}|{type}))*
+    """.format(
+        type=re_type, container_type=re_simple_container_type
+    )
+
+    re_xref = fr"""
         (?::\w+:)?                    # optional tag
-        `{0}`                         # what to reference
-        """.format(re_type)
+        `{re_type}`                   # what to reference
+        """
 
-    re_param_raw = r"""
+    re_param_raw = fr"""
         :                       # initial colon
         (?:                     # Sphinx keywords
         param|parameter|
@@ -230,51 +277,43 @@ class SphinxDocstring(Docstring):
         \s+                     # whitespace
 
         (?:                     # optional type declaration
-        ({type}|{container_type})
+        ({re_type}|{re_simple_container_type})
         \s+
         )?
 
-        (\w+)                   # Parameter name
-        \s*                     # whitespace
-        :                       # final colon
-        """.format(type=re_type, container_type=re_simple_container_type)
+        ((\\\*{{1,2}}\w+)|(\w+))  # Parameter name with potential asterisks
+        \s*                       # whitespace
+        :                         # final colon
+        """
     re_param_in_docstring = re.compile(re_param_raw, re.X | re.S)
 
-    re_type_raw = r"""
-        :type                   # Sphinx keyword
-        \s+                     # whitespace
-        ({type})                # Parameter name
-        \s*                     # whitespace
-        :                       # final colon
-        """.format(type=re_type)
+    re_type_raw = fr"""
+        :type                           # Sphinx keyword
+        \s+                             # whitespace
+        ({re_multiple_simple_type})     # Parameter name
+        \s*                             # whitespace
+        :                               # final colon
+        """
     re_type_in_docstring = re.compile(re_type_raw, re.X | re.S)
 
-    re_property_type_raw = r"""
-        :type:                  # Sphinx keyword
-        \s+                     # whitespace
-        {type}                  # type declaration
-        """.format(type=re_type)
-    re_property_type_in_docstring = re.compile(
-        re_property_type_raw, re.X | re.S
-    )
+    re_property_type_raw = fr"""
+        :type:                      # Sphinx keyword
+        \s+                         # whitespace
+        {re_multiple_simple_type}   # type declaration
+        """
+    re_property_type_in_docstring = re.compile(re_property_type_raw, re.X | re.S)
 
-    re_raise_raw = r"""
-        :                       # initial colon
-        (?:                     # Sphinx keyword
+    re_raise_raw = fr"""
+        :                               # initial colon
+        (?:                             # Sphinx keyword
         raises?|
         except|exception
         )
-        \s+                     # whitespace
-
-        (?:                     # type declaration
-        ({type})
-        \s+
-        )?
-
-        (\w+)                   # Parameter name
-        \s*                     # whitespace
-        :                       # final colon
-        """.format(type=re_type)
+        \s+                             # whitespace
+        ({re_multiple_simple_type})     # exception type
+        \s*                             # whitespace
+        :                               # final colon
+        """
     re_raise_in_docstring = re.compile(re_raise_raw, re.X | re.S)
 
     re_rtype_in_docstring = re.compile(r":rtype:")
@@ -284,18 +323,20 @@ class SphinxDocstring(Docstring):
     supports_yields = False
 
     def is_valid(self):
-        return bool(self.re_param_in_docstring.search(self.doc) or
-                    self.re_raise_in_docstring.search(self.doc) or
-                    self.re_rtype_in_docstring.search(self.doc) or
-                    self.re_returns_in_docstring.search(self.doc) or
-                    self.re_property_type_in_docstring.search(self.doc))
+        return bool(
+            self.re_param_in_docstring.search(self.doc)
+            or self.re_raise_in_docstring.search(self.doc)
+            or self.re_rtype_in_docstring.search(self.doc)
+            or self.re_returns_in_docstring.search(self.doc)
+            or self.re_property_type_in_docstring.search(self.doc)
+        )
 
     def exceptions(self):
         types = set()
 
         for match in re.finditer(self.re_raise_in_docstring, self.doc):
-            raise_type = match.group(2)
-            types.add(raise_type)
+            raise_type = match.group(1)
+            types.update(_split_multiple_exc_types(raise_type))
 
         return types
 
@@ -323,7 +364,7 @@ class SphinxDocstring(Docstring):
 
         # The summary line is the return doc,
         # so the first line must not be a known directive.
-        return not self.doc.lstrip().startswith(':')
+        return not self.doc.lstrip().startswith(":")
 
     def has_property_type(self):
         if not self.doc:
@@ -337,6 +378,8 @@ class SphinxDocstring(Docstring):
 
         for match in re.finditer(self.re_param_in_docstring, self.doc):
             name = match.group(2)
+            # Remove escape characters necessary for asterisks
+            name = name.replace("\\", "")
             params_with_doc.add(name)
             param_type = match.group(1)
             if param_type is not None:
@@ -356,29 +399,33 @@ class EpytextDocstring(SphinxDocstring):
         https://www.jetbrains.com/help/pycharm/2016.1/creating-documentation-comments.html#d848203e314
         https://www.jetbrains.com/help/pycharm/2016.1/using-docstrings-to-specify-types.html
     """
+
     re_param_in_docstring = re.compile(
-        SphinxDocstring.re_param_raw.replace(':', '@', 1),
-        re.X | re.S)
+        SphinxDocstring.re_param_raw.replace(":", "@", 1), re.X | re.S
+    )
 
     re_type_in_docstring = re.compile(
-        SphinxDocstring.re_type_raw.replace(':', '@', 1),
-        re.X | re.S)
+        SphinxDocstring.re_type_raw.replace(":", "@", 1), re.X | re.S
+    )
 
     re_property_type_in_docstring = re.compile(
-        SphinxDocstring.re_property_type_raw.replace(':', '@', 1),
-        re.X | re.S)
+        SphinxDocstring.re_property_type_raw.replace(":", "@", 1), re.X | re.S
+    )
 
     re_raise_in_docstring = re.compile(
-        SphinxDocstring.re_raise_raw.replace(':', '@', 1),
-        re.X | re.S)
+        SphinxDocstring.re_raise_raw.replace(":", "@", 1), re.X | re.S
+    )
 
-    re_rtype_in_docstring = re.compile(r"""
+    re_rtype_in_docstring = re.compile(
+        r"""
         @                       # initial "at" symbol
         (?:                     # Epytext keyword
         rtype|returntype
         )
         :                       # final colon
-        """, re.X | re.S)
+        """,
+        re.X | re.S,
+    )
 
     re_returns_in_docstring = re.compile(r"@returns?:")
 
@@ -390,7 +437,7 @@ class EpytextDocstring(SphinxDocstring):
         if self.has_property_type():
             # The summary line is the return doc,
             # so the first line must not be a known directive.
-            return not self.doc.lstrip().startswith('@')
+            return not self.doc.lstrip().startswith("@")
 
         return False
 
@@ -400,15 +447,17 @@ class GoogleDocstring(Docstring):
 
     re_xref = SphinxDocstring.re_xref
 
-    re_container_type = r"""
-        (?:{type}|{xref})             # a container type
+    re_container_type = fr"""
+        (?:{re_type}|{re_xref})       # a container type
         [\(\[] [^\n]+ [\)\]]          # with the contents of the container
-    """.format(type=re_type, xref=re_xref)
+    """
 
     re_multiple_type = r"""
         (?:{container_type}|{type}|{xref})
-        (?:\s+or\s+(?:{container_type}|{type}|{xref}))*
-    """.format(type=re_type, xref=re_xref, container_type=re_container_type)
+        (?:(?:\s+(?:of|or)\s+|\s*,\s*)(?:{container_type}|{type}|{xref}))*
+    """.format(
+        type=re_type, xref=re_xref, container_type=re_container_type
+    )
 
     _re_section_template = r"""
         ^([ ]*)   {0} \s*:   \s*$     # Google parameter header
@@ -417,57 +466,60 @@ class GoogleDocstring(Docstring):
 
     re_param_section = re.compile(
         _re_section_template.format(r"(?:Args|Arguments|Parameters)"),
-        re.X | re.S | re.M
+        re.X | re.S | re.M,
     )
 
     re_keyword_param_section = re.compile(
         _re_section_template.format(r"Keyword\s(?:Args|Arguments|Parameters)"),
-        re.X | re.S | re.M
+        re.X | re.S | re.M,
     )
 
-    re_param_line = re.compile(r"""
-        \s*  \*{{0,2}}(\w+)             # identifier potentially with asterisks
+    re_param_line = re.compile(
+        fr"""
+        \s*  (\*{{0,2}}\w+)             # identifier potentially with asterisks
         \s*  ( [(]
-            {type}
+            {re_multiple_type}
             (?:,\s+optional)?
             [)] )? \s* :                # optional type declaration
         \s*  (.*)                       # beginning of optional description
-    """.format(
-        type=re_multiple_type,
-    ), re.X | re.S | re.M)
+    """,
+        re.X | re.S | re.M,
+    )
 
     re_raise_section = re.compile(
-        _re_section_template.format(r"Raises"),
-        re.X | re.S | re.M
+        _re_section_template.format(r"Raises"), re.X | re.S | re.M
     )
 
-    re_raise_line = re.compile(r"""
-        \s*  ({type}) \s* :              # identifier
+    re_raise_line = re.compile(
+        fr"""
+        \s*  ({re_multiple_type}) \s* :  # identifier
         \s*  (.*)                        # beginning of optional description
-    """.format(type=re_type), re.X | re.S | re.M)
+    """,
+        re.X | re.S | re.M,
+    )
 
     re_returns_section = re.compile(
-        _re_section_template.format(r"Returns?"),
-        re.X | re.S | re.M
+        _re_section_template.format(r"Returns?"), re.X | re.S | re.M
     )
 
-    re_returns_line = re.compile(r"""
-        \s* ({type}:)?                    # identifier
+    re_returns_line = re.compile(
+        fr"""
+        \s* ({re_multiple_type}:)?        # identifier
         \s* (.*)                          # beginning of description
-    """.format(
-        type=re_multiple_type,
-    ), re.X | re.S | re.M)
+    """,
+        re.X | re.S | re.M,
+    )
 
-    re_property_returns_line = re.compile(r"""
-        ^{type}:                       # indentifier
+    re_property_returns_line = re.compile(
+        fr"""
+        ^{re_multiple_type}:           # indentifier
         \s* (.*)                       # Summary line / description
-    """.format(
-        type=re_multiple_type,
-    ), re.X | re.S | re.M)
+    """,
+        re.X | re.S | re.M,
+    )
 
     re_yields_section = re.compile(
-        _re_section_template.format(r"Yields?"),
-        re.X | re.S | re.M
+        _re_section_template.format(r"Yields?"), re.X | re.S | re.M
     )
 
     re_yields_line = re_returns_line
@@ -475,11 +527,13 @@ class GoogleDocstring(Docstring):
     supports_yields = True
 
     def is_valid(self):
-        return bool(self.re_param_section.search(self.doc) or
-                    self.re_raise_section.search(self.doc) or
-                    self.re_returns_section.search(self.doc) or
-                    self.re_yields_section.search(self.doc) or
-                    self.re_property_returns_line.search(self._first_line()))
+        return bool(
+            self.re_param_section.search(self.doc)
+            or self.re_raise_section.search(self.doc)
+            or self.re_returns_section.search(self.doc)
+            or self.re_yields_section.search(self.doc)
+            or self.re_property_returns_line.search(self._first_line())
+        )
 
     def has_params(self):
         if not self.doc:
@@ -523,10 +577,12 @@ class GoogleDocstring(Docstring):
         # The summary line is the return doc,
         # so the first line must not be a known directive.
         first_line = self._first_line()
-        return not bool(self.re_param_section.search(first_line) or
-                        self.re_raise_section.search(first_line) or
-                        self.re_returns_section.search(first_line) or
-                        self.re_yields_section.search(first_line))
+        return not bool(
+            self.re_param_section.search(first_line)
+            or self.re_raise_section.search(first_line)
+            or self.re_returns_section.search(first_line)
+            or self.re_yields_section.search(first_line)
+        )
 
     def has_property_type(self):
         if not self.doc:
@@ -578,7 +634,7 @@ class GoogleDocstring(Docstring):
             exc_type = match.group(1)
             exc_desc = match.group(2)
             if exc_desc:
-                types.add(exc_type)
+                types.update(_split_multiple_exc_types(exc_type))
 
         return types
 
@@ -596,6 +652,7 @@ class GoogleDocstring(Docstring):
             param_name = match.group(1)
             param_type = match.group(2)
             param_desc = match.group(3)
+
             if param_type:
                 params_with_type.add(param_name)
 
@@ -605,7 +662,7 @@ class GoogleDocstring(Docstring):
         return params_with_doc, params_with_type
 
     def _first_line(self):
-        return self.doc.lstrip().split('\n', 1)[0]
+        return self.doc.lstrip().split("\n", 1)[0]
 
     @staticmethod
     def min_section_indent(section_match):
@@ -666,66 +723,97 @@ class NumpyDocstring(GoogleDocstring):
 
     re_param_section = re.compile(
         _re_section_template.format(r"(?:Args|Arguments|Parameters)"),
-        re.X | re.S | re.M
+        re.X | re.S | re.M,
     )
 
-    re_param_line = re.compile(r"""
-        \s*  (\w+)                      # identifier
-        \s*  :
-        \s*  (?:({type})(?:,\s+optional)?)? # optional type declaration
-        \n                              # description starts on a new line
-        \s* (.*)                        # description
-    """.format(
-        type=GoogleDocstring.re_multiple_type,
-    ), re.X | re.S)
+    re_param_line = re.compile(
+        fr"""
+        \s*  (\*{{0,2}}\w+)(\s?(:|\n))                                      # identifier with potential asterisks
+        \s*  (?:({GoogleDocstring.re_multiple_type})(?:,\s+optional)?\n)?   # optional type declaration
+        \s* (.*)                                                            # optional description
+    """,
+        re.X | re.S,
+    )
 
     re_raise_section = re.compile(
-        _re_section_template.format(r"Raises"),
-        re.X | re.S | re.M
+        _re_section_template.format(r"Raises"), re.X | re.S | re.M
     )
 
-    re_raise_line = re.compile(r"""
-        \s* ({type})$   # type declaration
-        \s* (.*)        # optional description
-    """.format(type=GoogleDocstring.re_type), re.X | re.S | re.M)
+    re_raise_line = re.compile(
+        fr"""
+        \s* ({GoogleDocstring.re_type})$   # type declaration
+        \s* (.*)                           # optional description
+    """,
+        re.X | re.S | re.M,
+    )
 
     re_returns_section = re.compile(
-        _re_section_template.format(r"Returns?"),
-        re.X | re.S | re.M
+        _re_section_template.format(r"Returns?"), re.X | re.S | re.M
     )
 
-    re_returns_line = re.compile(r"""
+    re_returns_line = re.compile(
+        fr"""
         \s* (?:\w+\s+:\s+)? # optional name
-        ({type})$                         # type declaration
-        \s* (.*)                          # optional description
-    """.format(
-        type=GoogleDocstring.re_multiple_type,
-    ), re.X | re.S | re.M)
+        ({GoogleDocstring.re_multiple_type})$   # type declaration
+        \s* (.*)                                # optional description
+    """,
+        re.X | re.S | re.M,
+    )
 
     re_yields_section = re.compile(
-        _re_section_template.format(r"Yields?"),
-        re.X | re.S | re.M
+        _re_section_template.format(r"Yields?"), re.X | re.S | re.M
     )
 
     re_yields_line = re_returns_line
 
     supports_yields = True
 
+    def match_param_docs(self) -> Tuple[Set[str], Set[str]]:
+        """Matches parameter documentation section to parameter documentation rules"""
+        params_with_doc = set()
+        params_with_type = set()
+
+        entries = self._parse_section(self.re_param_section)
+        entries.extend(self._parse_section(self.re_keyword_param_section))
+        for entry in entries:
+            match = self.re_param_line.match(entry)
+            if not match:
+                continue
+
+            # check if parameter has description only
+            re_only_desc = re.match(r"\s*  (\*{0,2}\w+)\s*:?\n", entry)
+            if re_only_desc:
+                param_name = match.group(1)
+                param_desc = match.group(2)
+                param_type = None
+            else:
+                param_name = match.group(1)
+                param_type = match.group(3)
+                param_desc = match.group(4)
+
+            if param_type:
+                params_with_type.add(param_name)
+
+            if param_desc:
+                params_with_doc.add(param_name)
+
+        return params_with_doc, params_with_type
+
     @staticmethod
     def min_section_indent(section_match):
         return len(section_match.group(1))
 
     @staticmethod
     def _is_section_header(line):
-        return bool(re.match(r'\s*-+$', line))
+        return bool(re.match(r"\s*-+$", line))
 
 
 DOCSTRING_TYPES = {
-    'sphinx': SphinxDocstring,
-    'epytext': EpytextDocstring,
-    'google': GoogleDocstring,
-    'numpy': NumpyDocstring,
-    'default': Docstring,
+    "sphinx": SphinxDocstring,
+    "epytext": EpytextDocstring,
+    "google": GoogleDocstring,
+    "numpy": NumpyDocstring,
+    "default": Docstring,
 }
 """A map of the name of the docstring type to its class.
 
