@@ -8,9 +8,13 @@
 # Copyright (c) 2020 Damien Baty <damien.baty@polyconseil.fr>
 # Copyright (c) 2020 谭九鼎 <109224573@qq.com>
 # Copyright (c) 2020 Benjamin Graham <benwilliamgraham@gmail.com>
+# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
+# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
+# Copyright (c) 2021 Andreas Finkler <andi.finkler@gmail.com>
+# Copyright (c) 2021 Andrew Howe <howeaj@users.noreply.github.com>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
+# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
 
 """Graph manipulation utilities.
 
@@ -18,17 +22,18 @@
 """
 import codecs
 import os
+import shutil
 import subprocess
 import sys
 import tempfile
-from os import path as osp
+from typing import Optional
 
 
 def target_info_from_filename(filename):
     """Transforms /some/path/foo.png into ('/some/path', 'foo.png', 'png')."""
-    basename = osp.basename(filename)
-    storedir = osp.dirname(osp.abspath(filename))
-    target = filename.split(".")[-1]
+    basename = os.path.basename(filename)
+    storedir = os.path.dirname(os.path.abspath(filename))
+    target = os.path.splitext(filename)[-1][1:]
     return storedir, basename, target
 
 
@@ -51,18 +56,20 @@ class DotBackend:
         self.renderer = renderer
         self.lines = []
         self._source = None
-        self.emit("digraph %s {" % normalize_node_id(graphname))
+        self.emit(f"digraph {normalize_node_id(graphname)} {{")
         if rankdir:
-            self.emit("rankdir=%s" % rankdir)
+            self.emit(f"rankdir={rankdir}")
         if ratio:
-            self.emit("ratio=%s" % ratio)
+            self.emit(f"ratio={ratio}")
         if size:
-            self.emit('size="%s"' % size)
+            self.emit(f'size="{size}"')
         if charset:
-            assert charset.lower() in ("utf-8", "iso-8859-1", "latin1"), (
-                "unsupported charset %s" % charset
-            )
-            self.emit('charset="%s"' % charset)
+            assert charset.lower() in {
+                "utf-8",
+                "iso-8859-1",
+                "latin1",
+            }, f"unsupported charset {charset}"
+            self.emit(f'charset="{charset}"')
         for param in additional_param.items():
             self.emit("=".join(param))
 
@@ -76,7 +83,9 @@ class DotBackend:
 
     source = property(get_source)
 
-    def generate(self, outputfile=None, mapfile=None):
+    def generate(
+        self, outputfile: Optional[str] = None, mapfile: Optional[str] = None
+    ) -> str:
         """Generates a graph file.
 
         :param str outputfile: filename and path [defaults to graphname.png]
@@ -84,25 +93,35 @@ class DotBackend:
 
         :rtype: str
         :return: a path to the generated file
+        :raises RuntimeError: if the executable for rendering was not found
         """
+        graphviz_extensions = ("dot", "gv")
         name = self.graphname
-        if outputfile is not None:
-            _, _, target = target_info_from_filename(outputfile)
-            if target != "dot":
-                pdot, dot_sourcepath = tempfile.mkstemp(".dot", name)
-                os.close(pdot)
-            else:
-                dot_sourcepath = outputfile
-        else:
+        if outputfile is None:
             target = "png"
-            pdot, dot_sourcepath = tempfile.mkstemp(".dot", name)
+            pdot, dot_sourcepath = tempfile.mkstemp(".gv", name)
             ppng, outputfile = tempfile.mkstemp(".png", name)
             os.close(pdot)
             os.close(ppng)
-        pdot = codecs.open(dot_sourcepath, "w", encoding="utf8")
-        pdot.write(self.source)
-        pdot.close()
-        if target != "dot":
+        else:
+            _, _, target = target_info_from_filename(outputfile)
+            if not target:
+                target = "png"
+                outputfile = outputfile + "." + target
+            if target not in graphviz_extensions:
+                pdot, dot_sourcepath = tempfile.mkstemp(".gv", name)
+                os.close(pdot)
+            else:
+                dot_sourcepath = outputfile
+        with codecs.open(dot_sourcepath, "w", encoding="utf8") as file:
+            file.write(self.source)
+        if target not in graphviz_extensions:
+            if shutil.which(self.renderer) is None:
+                raise RuntimeError(
+                    f"Cannot generate `{outputfile}` because '{self.renderer}' "
+                    "executable not found. Install graphviz, or specify a `.gv` "
+                    "outputfile to produce the DOT source code."
+                )
             use_shell = sys.platform == "win32"
             if mapfile:
                 subprocess.call(
@@ -137,19 +156,19 @@ class DotBackend:
         """
         attrs = [f'{prop}="{value}"' for prop, value in props.items()]
         n_from, n_to = normalize_node_id(name1), normalize_node_id(name2)
-        self.emit("{} -> {} [{}];".format(n_from, n_to, ", ".join(sorted(attrs))))
+        self.emit(f"{n_from} -> {n_to} [{', '.join(sorted(attrs))}];")
 
     def emit_node(self, name, **props):
         """emit a node with given properties.
         node properties: see https://www.graphviz.org/doc/info/attrs.html
         """
         attrs = [f'{prop}="{value}"' for prop, value in props.items()]
-        self.emit("{} [{}];".format(normalize_node_id(name), ", ".join(sorted(attrs))))
+        self.emit(f"{normalize_node_id(name)} [{', '.join(sorted(attrs))}];")
 
 
 def normalize_node_id(nid):
     """Returns a suitable DOT node id for `nid`."""
-    return '"%s"' % nid
+    return f'"{nid}"'
 
 
 def get_cycles(graph_dict, vertices=None):
