@@ -6,9 +6,13 @@
 # Copyright (c) 2019 Hugo van Kemenade <hugovk@users.noreply.github.com>
 # Copyright (c) 2020 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2020 Anthony Sottile <asottile@umich.edu>
+# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
+# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
+# Copyright (c) 2021 Nick Drozd <nicholasdrozd@gmail.com>
+# Copyright (c) 2021 Mark Byrne <31762852+mbyrnepr2@users.noreply.github.com>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
+# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
 
 """
 Visitor doing some postprocessing on the astroid tree.
@@ -19,7 +23,7 @@ import os
 import traceback
 
 import astroid
-from astroid import bases, exceptions, manager, modutils, node_classes
+from astroid import nodes
 
 from pylint.pyreverse import utils
 
@@ -30,10 +34,10 @@ def _iface_hdlr(_):
 
 
 def _astroid_wrapper(func, modname):
-    print("parsing %s..." % modname)
+    print(f"parsing {modname}...")
     try:
         return func(modname)
-    except exceptions.AstroidBuildingException as exc:
+    except astroid.exceptions.AstroidBuildingException as exc:
         print(exc)
     except Exception:  # pylint: disable=broad-except
         traceback.print_exc()
@@ -43,14 +47,14 @@ def _astroid_wrapper(func, modname):
 def interfaces(node, herited=True, handler_func=_iface_hdlr):
     """Return an iterator on interfaces implemented by the given class node."""
     try:
-        implements = bases.Instance(node).getattr("__implements__")[0]
-    except exceptions.NotFoundError:
+        implements = astroid.bases.Instance(node).getattr("__implements__")[0]
+    except astroid.exceptions.NotFoundError:
         return
     if not herited and implements.frame() is not node:
         return
     found = set()
     missing = False
-    for iface in node_classes.unpack_infer(implements):
+    for iface in nodes.unpack_infer(implements):
         if iface is astroid.Uninferable:
             missing = True
             continue
@@ -58,7 +62,7 @@ def interfaces(node, herited=True, handler_func=_iface_hdlr):
             found.add(iface)
             yield iface
     if missing:
-        raise exceptions.InferenceError()
+        raise astroid.exceptions.InferenceError()
 
 
 class IdGeneratorMixIn:
@@ -77,6 +81,35 @@ class IdGeneratorMixIn:
         return self.id_count
 
 
+class Project:
+    """a project handle a set of modules / packages"""
+
+    def __init__(self, name=""):
+        self.name = name
+        self.uid = None
+        self.path = None
+        self.modules = []
+        self.locals = {}
+        self.__getitem__ = self.locals.__getitem__
+        self.__iter__ = self.locals.__iter__
+        self.values = self.locals.values
+        self.keys = self.locals.keys
+        self.items = self.locals.items
+
+    def add_module(self, node):
+        self.locals[node.name] = node
+        self.modules.append(node)
+
+    def get_module(self, name):
+        return self.locals[name]
+
+    def get_children(self):
+        return self.modules
+
+    def __repr__(self):
+        return f"<Project {self.name!r} at {id(self)} ({len(self.modules)} modules)>"
+
+
 class Linker(IdGeneratorMixIn, utils.LocalsVisitor):
     """Walk on the project tree and resolve relationships.
 
@@ -110,7 +143,7 @@ class Linker(IdGeneratorMixIn, utils.LocalsVisitor):
         # visited project
         self.project = project
 
-    def visit_project(self, node):
+    def visit_project(self, node: Project) -> None:
         """visit a pyreverse.utils.Project node
 
         * optionally tag the node with a unique id
@@ -120,17 +153,7 @@ class Linker(IdGeneratorMixIn, utils.LocalsVisitor):
         for module in node.modules:
             self.visit(module)
 
-    def visit_package(self, node):
-        """visit an astroid.Package node
-
-        * optionally tag the node with a unique id
-        """
-        if self.tag:
-            node.uid = self.generate_id()
-        for subelmt in node.values():
-            self.visit(subelmt)
-
-    def visit_module(self, node):
+    def visit_module(self, node: nodes.Module) -> None:
         """visit an astroid.Module node
 
         * set the locals_type mapping
@@ -144,7 +167,7 @@ class Linker(IdGeneratorMixIn, utils.LocalsVisitor):
         if self.tag:
             node.uid = self.generate_id()
 
-    def visit_classdef(self, node):
+    def visit_classdef(self, node: nodes.ClassDef) -> None:
         """visit an astroid.Class node
 
         * set the locals_type and instance_attrs_type mappings
@@ -165,15 +188,15 @@ class Linker(IdGeneratorMixIn, utils.LocalsVisitor):
         node.instance_attrs_type = collections.defaultdict(list)
         for assignattrs in node.instance_attrs.values():
             for assignattr in assignattrs:
-                if not isinstance(assignattr, astroid.Unknown):
+                if not isinstance(assignattr, nodes.Unknown):
                     self.handle_assignattr_type(assignattr, node)
         # resolve implemented interface
         try:
             node.implements = list(interfaces(node, self.inherited_interfaces))
         except astroid.InferenceError:
-            node.implements = ()
+            node.implements = []
 
-    def visit_functiondef(self, node):
+    def visit_functiondef(self, node: nodes.FunctionDef) -> None:
         """visit an astroid.Function node
 
         * set the locals_type mapping
@@ -190,7 +213,7 @@ class Linker(IdGeneratorMixIn, utils.LocalsVisitor):
     link_class = visit_classdef
     link_function = visit_functiondef
 
-    def visit_assignname(self, node):
+    def visit_assignname(self, node: nodes.AssignName) -> None:
         """visit an astroid.AssignName node
 
         handle locals_type
@@ -206,23 +229,19 @@ class Linker(IdGeneratorMixIn, utils.LocalsVisitor):
             # the name has been defined as 'global' in the frame and belongs
             # there.
             frame = node.root()
-        try:
-            if not hasattr(frame, "locals_type"):
-                # If the frame doesn't have a locals_type yet,
-                # it means it wasn't yet visited. Visit it now
-                # to add what's missing from it.
-                if isinstance(frame, astroid.ClassDef):
-                    self.visit_classdef(frame)
-                elif isinstance(frame, astroid.FunctionDef):
-                    self.visit_functiondef(frame)
-                else:
-                    self.visit_module(frame)
+        if not hasattr(frame, "locals_type"):
+            # If the frame doesn't have a locals_type yet,
+            # it means it wasn't yet visited. Visit it now
+            # to add what's missing from it.
+            if isinstance(frame, nodes.ClassDef):
+                self.visit_classdef(frame)
+            elif isinstance(frame, nodes.FunctionDef):
+                self.visit_functiondef(frame)
+            else:
+                self.visit_module(frame)
 
-            current = frame.locals_type[node.name]
-            values = set(node.infer())
-            frame.locals_type[node.name] = list(set(current) | values)
-        except astroid.InferenceError:
-            pass
+        current = frame.locals_type[node.name]
+        frame.locals_type[node.name] = list(set(current) | utils.infer_node(node))
 
     @staticmethod
     def handle_assignattr_type(node, parent):
@@ -230,24 +249,22 @@ class Linker(IdGeneratorMixIn, utils.LocalsVisitor):
 
         handle instance_attrs_type
         """
-        try:
-            values = set(node.infer())
-            current = set(parent.instance_attrs_type[node.attrname])
-            parent.instance_attrs_type[node.attrname] = list(current | values)
-        except astroid.InferenceError:
-            pass
+        current = set(parent.instance_attrs_type[node.attrname])
+        parent.instance_attrs_type[node.attrname] = list(
+            current | utils.infer_node(node)
+        )
 
-    def visit_import(self, node):
+    def visit_import(self, node: nodes.Import) -> None:
         """visit an astroid.Import node
 
         resolve module dependencies
         """
         context_file = node.root().file
         for name in node.names:
-            relative = modutils.is_relative(name[0], context_file)
+            relative = astroid.modutils.is_relative(name[0], context_file)
             self._imported_module(node, name[0], relative)
 
-    def visit_importfrom(self, node):
+    def visit_importfrom(self, node: nodes.ImportFrom) -> None:
         """visit an astroid.ImportFrom node
 
         resolve module dependencies
@@ -255,7 +272,7 @@ class Linker(IdGeneratorMixIn, utils.LocalsVisitor):
         basename = node.modname
         context_file = node.root().file
         if context_file is not None:
-            relative = modutils.is_relative(basename, context_file)
+            relative = astroid.modutils.is_relative(basename, context_file)
         else:
             relative = False
         for name in node.names:
@@ -265,7 +282,7 @@ class Linker(IdGeneratorMixIn, utils.LocalsVisitor):
             fullname = f"{basename}.{name[0]}"
             if fullname.find(".") > -1:
                 try:
-                    fullname = modutils.get_module_part(fullname, context_file)
+                    fullname = astroid.modutils.get_module_part(fullname, context_file)
                 except ImportError:
                     continue
             if fullname != basename:
@@ -276,7 +293,7 @@ class Linker(IdGeneratorMixIn, utils.LocalsVisitor):
         package_dir = os.path.dirname(self.project.path)
         if context_name == mod_path:
             return 0
-        if modutils.is_standard_module(mod_path, (package_dir,)):
+        if astroid.modutils.is_standard_module(mod_path, (package_dir,)):
             return 1
         return 0
 
@@ -285,7 +302,7 @@ class Linker(IdGeneratorMixIn, utils.LocalsVisitor):
         module = node.root()
         context_name = module.name
         if relative:
-            mod_path = "{}.{}".format(".".join(context_name.split(".")[:-1]), mod_path)
+            mod_path = f"{'.'.join(context_name.split('.')[:-1])}.{mod_path}"
         if self.compute_module(context_name, mod_path):
             # handle dependencies
             if not hasattr(module, "depends"):
@@ -295,44 +312,16 @@ class Linker(IdGeneratorMixIn, utils.LocalsVisitor):
                 mod_paths.append(mod_path)
 
 
-class Project:
-    """a project handle a set of modules / packages"""
-
-    def __init__(self, name=""):
-        self.name = name
-        self.path = None
-        self.modules = []
-        self.locals = {}
-        self.__getitem__ = self.locals.__getitem__
-        self.__iter__ = self.locals.__iter__
-        self.values = self.locals.values
-        self.keys = self.locals.keys
-        self.items = self.locals.items
-
-    def add_module(self, node):
-        self.locals[node.name] = node
-        self.modules.append(node)
-
-    def get_module(self, name):
-        return self.locals[name]
-
-    def get_children(self):
-        return self.modules
-
-    def __repr__(self):
-        return f"<Project {self.name!r} at {id(self)} ({len(self.modules)} modules)>"
-
-
 def project_from_files(
     files, func_wrapper=_astroid_wrapper, project_name="no name", black_list=("CVS",)
 ):
     """return a Project from a list of files or modules"""
     # build the project representation
-    astroid_manager = manager.AstroidManager()
+    astroid_manager = astroid.manager.AstroidManager()
     project = Project(project_name)
     for something in files:
         if not os.path.exists(something):
-            fpath = modutils.file_from_modpath(something.split("."))
+            fpath = astroid.modutils.file_from_modpath(something.split("."))
         elif os.path.isdir(something):
             fpath = os.path.join(something, "__init__.py")
         else:
@@ -346,7 +335,7 @@ def project_from_files(
         # recurse in package except if __init__ was explicitly given
         if ast.package and something.find("__init__") == -1:
             # recurse on others packages / modules if this is a package
-            for fpath in modutils.get_module_files(
+            for fpath in astroid.modutils.get_module_files(
                 os.path.dirname(ast.file), black_list
             ):
                 ast = func_wrapper(astroid_manager.ast_from_file, fpath)
