@@ -18,8 +18,8 @@
 # Copyright (c) 2016 Glenn Matthews <glmatthe@cisco.com>
 # Copyright (c) 2016 Ashley Whetter <ashley@awhetter.co.uk>
 # Copyright (c) 2016 xmo-odoo <xmo-odoo@users.noreply.github.com>
-# Copyright (c) 2017 Pierre Sassoulas <pierre.sassoulas@cea.fr>
-# Copyright (c) 2017-2018, 2020 hippo91 <guillaume.peillex@gmail.com>
+# Copyright (c) 2017-2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
+# Copyright (c) 2017-2018, 2020-2021 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2017, 2020 Anthony Sottile <asottile@umich.edu>
 # Copyright (c) 2017-2018 Bryce Guinta <bryce.paul.guinta@gmail.com>
 # Copyright (c) 2017 Chris Lamb <chris@chris-lamb.co.uk>
@@ -27,35 +27,36 @@
 # Copyright (c) 2017 Mikhail Fesenko <proggga@gmail.com>
 # Copyright (c) 2017 Craig Citro <craigcitro@gmail.com>
 # Copyright (c) 2017 Ville Skyttä <ville.skytta@iki.fi>
-# Copyright (c) 2018-2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
-# Copyright (c) 2018 Pierre Sassoulas <pierre.sassoulas@wisebim.fr>
 # Copyright (c) 2018 ssolanki <sushobhitsolanki@gmail.com>
 # Copyright (c) 2018 Bryce Guinta <bryce.guinta@protonmail.com>
 # Copyright (c) 2018 Sushobhit <31987769+sushobhit27@users.noreply.github.com>
 # Copyright (c) 2018 Reverb C <reverbc@users.noreply.github.com>
 # Copyright (c) 2018 Nick Drozd <nicholasdrozd@gmail.com>
+# Copyright (c) 2020 Peter Kolbus <peter.kolbus@gmail.com>
 # Copyright (c) 2020 Damien Baty <damien.baty@polyconseil.fr>
+# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
+# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
+# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
 
 """some various utilities and helper classes, most of them used in the
 main pylint class
 """
 
 from pylint.utils.ast_walker import ASTWalker
+from pylint.utils.docs import print_full_documentation
 from pylint.utils.file_state import FileState
+from pylint.utils.linterstats import LinterStats, ModuleStats, merge_stats
 from pylint.utils.utils import (
     HAS_ISORT_5,
     IsortDriver,
-    _basename_in_blacklist_re,
     _check_csv,
     _format_option_value,
     _splitstrip,
     _unquote,
     decoding_stream,
-    deprecated_option,
-    expand_modules,
+    diff_string,
     format_section,
     get_global_option,
     get_module_and_frameid,
@@ -63,7 +64,6 @@ from pylint.utils.utils import (
     get_rst_title,
     normalize_text,
     register_plugins,
-    safe_decode,
     tokenize_module,
 )
 
@@ -71,14 +71,12 @@ __all__ = [
     "ASTWalker",
     "HAS_ISORT_5",
     "IsortDriver",
-    "_basename_in_blacklist_re",
     "_check_csv",
     "_format_option_value",
     "_splitstrip",
     "_unquote",
     "decoding_stream",
-    "deprecated_option",
-    "expand_modules",
+    "diff_string",
     "FileState",
     "format_section",
     "get_global_option",
@@ -87,6 +85,9 @@ __all__ = [
     "get_rst_title",
     "normalize_text",
     "register_plugins",
-    "safe_decode",
     "tokenize_module",
+    "merge_stats",
+    "LinterStats",
+    "ModuleStats",
+    "print_full_documentation",
 ]
