@@ -10,9 +10,13 @@
 # Copyright (c) 2019 agutole <toldo_carp@hotmail.com>
 # Copyright (c) 2020 Ganden Schaffner <gschaffner@pm.me>
 # Copyright (c) 2020 hippo91 <guillaume.peillex@gmail.com>
+# Copyright (c) 2021 Jaehoon Hwang <jaehoonhwang@users.noreply.github.com>
+# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
+# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
+# Copyright (c) 2021 Eli Fine <ejfine@gmail.com>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
+# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
 
 """Unittest for the spelling checker."""
 
@@ -20,7 +24,7 @@ import astroid
 import pytest
 
 from pylint.checkers import spelling
-from pylint.testutils import CheckerTestCase, Message, _tokenize_str, set_config
+from pylint.testutils import CheckerTestCase, MessageTest, _tokenize_str, set_config
 
 # try to create enchant dictionary
 try:
@@ -37,7 +41,9 @@ if enchant is not None:
         pass
 
 
-class TestSpellingChecker(CheckerTestCase):
+class TestSpellingChecker(CheckerTestCase):  # pylint:disable=too-many-public-methods
+    # This is a test case class, not sure why it would be relevant to have
+    #   this pylint rule enforced for test case classes.
     CHECKER_CLASS = spelling.SpellingChecker
 
     skip_on_missing_package_or_dict = pytest.mark.skipif(
@@ -53,7 +59,7 @@ class TestSpellingChecker(CheckerTestCase):
     @set_config(spelling_dict=spell_dict)
     def test_check_bad_coment(self):
         with self.assertAddsMessages(
-            Message(
+            MessageTest(
                 "wrong-spelling-in-comment",
                 line=1,
                 args=(
@@ -71,7 +77,7 @@ class TestSpellingChecker(CheckerTestCase):
     @set_config(max_spelling_suggestions=2)
     def test_check_bad_coment_custom_suggestion_count(self):
         with self.assertAddsMessages(
-            Message(
+            MessageTest(
                 "wrong-spelling-in-comment",
                 line=1,
                 args=(
@@ -89,7 +95,7 @@ class TestSpellingChecker(CheckerTestCase):
     def test_check_bad_docstring(self):
         stmt = astroid.extract_node('def fff():\n   """bad coment"""\n   pass')
         with self.assertAddsMessages(
-            Message(
+            MessageTest(
                 "wrong-spelling-in-docstring",
                 line=2,
                 args=(
@@ -104,7 +110,7 @@ class TestSpellingChecker(CheckerTestCase):
 
         stmt = astroid.extract_node('class Abc(object):\n   """bad coment"""\n   pass')
         with self.assertAddsMessages(
-            Message(
+            MessageTest(
                 "wrong-spelling-in-docstring",
                 line=2,
                 args=(
@@ -123,7 +129,7 @@ class TestSpellingChecker(CheckerTestCase):
     def test_invalid_docstring_characters(self):
         stmt = astroid.extract_node('def fff():\n   """test\\x00"""\n   pass')
         with self.assertAddsMessages(
-            Message("invalid-characters-in-docstring", line=2, args=("test\x00",))
+            MessageTest("invalid-characters-in-docstring", line=2, args=("test\x00",))
         ):
             self.checker.visit_functiondef(stmt)
 
@@ -131,30 +137,30 @@ class TestSpellingChecker(CheckerTestCase):
     @set_config(spelling_dict=spell_dict)
     def test_skip_shebangs(self):
         self.checker.process_tokens(_tokenize_str("#!/usr/bin/env python"))
-        assert self.linter.release_messages() == []
+        assert not self.linter.release_messages()
 
     @skip_on_missing_package_or_dict
     @set_config(spelling_dict=spell_dict)
     def test_skip_python_coding_comments(self):
         self.checker.process_tokens(_tokenize_str("# -*- coding: utf-8 -*-"))
-        assert self.linter.release_messages() == []
+        assert not self.linter.release_messages()
         self.checker.process_tokens(_tokenize_str("# coding=utf-8"))
-        assert self.linter.release_messages() == []
+        assert not self.linter.release_messages()
         self.checker.process_tokens(_tokenize_str("# vim: set fileencoding=utf-8 :"))
-        assert self.linter.release_messages() == []
+        assert not self.linter.release_messages()
         # Now with a shebang first
         self.checker.process_tokens(
             _tokenize_str("#!/usr/bin/env python\n# -*- coding: utf-8 -*-")
         )
-        assert self.linter.release_messages() == []
+        assert not self.linter.release_messages()
         self.checker.process_tokens(
             _tokenize_str("#!/usr/bin/env python\n# coding=utf-8")
         )
-        assert self.linter.release_messages() == []
+        assert not self.linter.release_messages()
         self.checker.process_tokens(
             _tokenize_str("#!/usr/bin/env python\n# vim: set fileencoding=utf-8 :")
         )
-        assert self.linter.release_messages() == []
+        assert not self.linter.release_messages()
 
     @skip_on_missing_package_or_dict
     @set_config(spelling_dict=spell_dict)
@@ -162,13 +168,13 @@ class TestSpellingChecker(CheckerTestCase):
         self.checker.process_tokens(
             _tokenize_str("# Line 1\n Line 2\n# pylint: disable=ungrouped-imports")
         )
-        assert self.linter.release_messages() == []
+        assert not self.linter.release_messages()
 
     @skip_on_missing_package_or_dict
     @set_config(spelling_dict=spell_dict)
     def test_skip_words_with_numbers(self):
         self.checker.process_tokens(_tokenize_str("\n# 0ne\n# Thr33\n# Sh3ll"))
-        assert self.linter.release_messages() == []
+        assert not self.linter.release_messages()
 
     @skip_on_missing_package_or_dict
     @set_config(spelling_dict=spell_dict)
@@ -177,7 +183,7 @@ class TestSpellingChecker(CheckerTestCase):
             'class ComentAbc(object):\n   """ComentAbc with a bad coment"""\n   pass'
         )
         with self.assertAddsMessages(
-            Message(
+            MessageTest(
                 "wrong-spelling-in-docstring",
                 line=2,
                 args=(
@@ -197,7 +203,7 @@ class TestSpellingChecker(CheckerTestCase):
             'class ComentAbc(object):\n   """comentAbc with a bad coment"""\n   pass'
         )
         with self.assertAddsMessages(
-            Message(
+            MessageTest(
                 "wrong-spelling-in-docstring",
                 line=2,
                 args=(
@@ -215,7 +221,7 @@ class TestSpellingChecker(CheckerTestCase):
             'class ComentAbc(object):\n   """argumentN with a bad coment"""\n   pass'
         )
         with self.assertAddsMessages(
-            Message(
+            MessageTest(
                 "wrong-spelling-in-docstring",
                 line=2,
                 args=(
@@ -240,7 +246,7 @@ class TestSpellingChecker(CheckerTestCase):
                 f'class TestClass(object):\n   """{ccn} comment"""\n   pass'
             )
             self.checker.visit_classdef(stmt)
-            assert self.linter.release_messages() == []
+            assert not self.linter.release_messages()
 
     @skip_on_missing_package_or_dict
     @set_config(spelling_dict=spell_dict)
@@ -249,19 +255,19 @@ class TestSpellingChecker(CheckerTestCase):
             'def fff(param_name):\n   """test param_name"""\n   pass'
         )
         self.checker.visit_functiondef(stmt)
-        assert self.linter.release_messages() == []
+        assert not self.linter.release_messages()
 
     @skip_on_missing_package_or_dict
     @set_config(spelling_dict=spell_dict)
     def test_skip_email_address(self):
         self.checker.process_tokens(_tokenize_str("# uname@domain.tld"))
-        assert self.linter.release_messages() == []
+        assert not self.linter.release_messages()
 
     @skip_on_missing_package_or_dict
     @set_config(spelling_dict=spell_dict)
     def test_skip_urls(self):
         self.checker.process_tokens(_tokenize_str("# https://github.com/rfk/pyenchant"))
-        assert self.linter.release_messages() == []
+        assert not self.linter.release_messages()
 
     @skip_on_missing_package_or_dict
     @set_config(spelling_dict=spell_dict)
@@ -270,7 +276,7 @@ class TestSpellingChecker(CheckerTestCase):
             'class ComentAbc(object):\n   """This is :class:`ComentAbc` with a bad coment"""\n   pass'
         )
         with self.assertAddsMessages(
-            Message(
+            MessageTest(
                 "wrong-spelling-in-docstring",
                 line=2,
                 args=(
@@ -290,7 +296,7 @@ class TestSpellingChecker(CheckerTestCase):
             'class ComentAbc(object):\n   """This is :py:attr:`ComentAbc` with a bad coment"""\n   pass'
         )
         with self.assertAddsMessages(
-            Message(
+            MessageTest(
                 "wrong-spelling-in-docstring",
                 line=2,
                 args=(
@@ -303,6 +309,107 @@ class TestSpellingChecker(CheckerTestCase):
         ):
             self.checker.visit_classdef(stmt)
 
+    @skip_on_missing_package_or_dict
+    @set_config(spelling_dict=spell_dict)
+    @pytest.mark.parametrize(
+        ",".join(
+            (
+                "misspelled_portion_of_directive",
+                "second_portion_of_directive",
+                "description",
+            )
+        ),
+        (
+            ("fmt", ": on", "black directive to turn on formatting"),
+            ("fmt", ": off", "black directive to turn off formatting"),
+            ("noqa", "", "pycharm directive"),
+            ("noqa", ":", "flake8 / zimports directive"),
+            ("nosec", "", "bandit directive"),
+            ("isort", ":skip", "isort directive"),
+            ("mypy", ":", "mypy directive"),
+        ),
+    )
+    def test_skip_tool_directives_at_beginning_of_comments_but_still_raise_error_if_directive_appears_later_in_comment(  # pylint:disable=unused-argument
+        # Having the extra description parameter allows the description
+        #   to show up in the pytest output as part of the test name
+        #   when running parametrized tests.
+        self,
+        misspelled_portion_of_directive,
+        second_portion_of_directive,
+        description,
+    ):
+        full_comment = f"# {misspelled_portion_of_directive}{second_portion_of_directive} {misspelled_portion_of_directive}"
+        with self.assertAddsMessages(
+            MessageTest(
+                "wrong-spelling-in-comment",
+                line=1,
+                args=(
+                    misspelled_portion_of_directive,
+                    full_comment,
+                    f"  {'^'*len(misspelled_portion_of_directive)}",
+                    self._get_msg_suggestions(misspelled_portion_of_directive),
+                ),
+            )
+        ):
+            self.checker.process_tokens(_tokenize_str(full_comment))
+
+    @skip_on_missing_package_or_dict
+    @set_config(spelling_dict=spell_dict)
+    def test_skip_code_flanked_in_double_backticks(self):
+        full_comment = "# The function ``.qsize()`` .qsize()"
+        with self.assertAddsMessages(
+            MessageTest(
+                "wrong-spelling-in-comment",
+                line=1,
+                args=(
+                    "qsize",
+                    full_comment,
+                    "                 ^^^^^",
+                    self._get_msg_suggestions("qsize"),
+                ),
+            )
+        ):
+            self.checker.process_tokens(_tokenize_str(full_comment))
+
+    @skip_on_missing_package_or_dict
+    @set_config(spelling_dict=spell_dict)
+    def test_skip_code_flanked_in_single_backticks(self):
+        full_comment = "# The function `.qsize()` .qsize()"
+        with self.assertAddsMessages(
+            MessageTest(
+                "wrong-spelling-in-comment",
+                line=1,
+                args=(
+                    "qsize",
+                    full_comment,
+                    "                 ^^^^^",
+                    self._get_msg_suggestions("qsize"),
+                ),
+            )
+        ):
+            self.checker.process_tokens(_tokenize_str(full_comment))
+
+    @skip_on_missing_package_or_dict
+    @set_config(
+        spelling_dict=spell_dict,
+        spelling_ignore_comment_directives="newdirective:,noqa",
+    )
+    def test_skip_directives_specified_in_pylintrc(self):
+        full_comment = "# newdirective: do this newdirective"
+        with self.assertAddsMessages(
+            MessageTest(
+                "wrong-spelling-in-comment",
+                line=1,
+                args=(
+                    "newdirective",
+                    full_comment,
+                    "          ^^^^^^^^^^^^",
+                    self._get_msg_suggestions("newdirective"),
+                ),
+            )
+        ):
+            self.checker.process_tokens(_tokenize_str(full_comment))
+
     @skip_on_missing_package_or_dict
     @set_config(spelling_dict=spell_dict)
     def test_handle_words_joined_by_forward_slash(self):
@@ -314,7 +421,7 @@ class TestSpellingChecker(CheckerTestCase):
         '''
         )
         with self.assertAddsMessages(
-            Message(
+            MessageTest(
                 "wrong-spelling-in-docstring",
                 line=3,
                 args=(
@@ -334,7 +441,7 @@ class TestSpellingChecker(CheckerTestCase):
             'class ComentAbc(object):\n   """Check teh dummy comment teh"""\n   pass'
         )
         with self.assertAddsMessages(
-            Message(
+            MessageTest(
                 "wrong-spelling-in-docstring",
                 line=2,
                 args=(
@@ -344,7 +451,7 @@ class TestSpellingChecker(CheckerTestCase):
                     self._get_msg_suggestions("teh"),
                 ),
             ),
-            Message(
+            MessageTest(
                 "wrong-spelling-in-docstring",
                 line=2,
                 args=(
@@ -361,7 +468,7 @@ class TestSpellingChecker(CheckerTestCase):
     @set_config(spelling_dict=spell_dict)
     def test_more_than_one_error_in_same_line_for_same_word_on_comment(self):
         with self.assertAddsMessages(
-            Message(
+            MessageTest(
                 "wrong-spelling-in-comment",
                 line=1,
                 args=(
@@ -371,7 +478,7 @@ class TestSpellingChecker(CheckerTestCase):
                     self._get_msg_suggestions("coment"),
                 ),
             ),
-            Message(
+            MessageTest(
                 "wrong-spelling-in-comment",
                 line=1,
                 args=(
@@ -388,15 +495,13 @@ class TestSpellingChecker(CheckerTestCase):
     @set_config(spelling_dict=spell_dict)
     def test_docstring_lines_that_look_like_comments_1(self):
         stmt = astroid.extract_node(
-            # fmt: off
-            'def f():\n'
-            '    """\n'
-            '    # msitake\n'
-            '    """'
-            # fmt: on
+            '''def f():
+    """
+    # msitake
+    """'''
         )
         with self.assertAddsMessages(
-            Message(
+            MessageTest(
                 "wrong-spelling-in-docstring",
                 line=3,
                 args=(
@@ -413,13 +518,11 @@ class TestSpellingChecker(CheckerTestCase):
     @set_config(spelling_dict=spell_dict)
     def test_docstring_lines_that_look_like_comments_2(self):
         stmt = astroid.extract_node(
-            # fmt: off
-            'def f():\n'
-            '    """# msitake"""'
-            # fmt: on
+            '''def f():
+    """# msitake"""'''
         )
         with self.assertAddsMessages(
-            Message(
+            MessageTest(
                 "wrong-spelling-in-docstring",
                 line=2,
                 args=(
@@ -436,15 +539,13 @@ class TestSpellingChecker(CheckerTestCase):
     @set_config(spelling_dict=spell_dict)
     def test_docstring_lines_that_look_like_comments_3(self):
         stmt = astroid.extract_node(
-            # fmt: off
-            'def f():\n'
-            '    """\n'
-            '# msitake\n'
-            '    """'
-            # fmt: on
+            '''def f():
+    """
+# msitake
+    """'''
         )
         with self.assertAddsMessages(
-            Message(
+            MessageTest(
                 "wrong-spelling-in-docstring",
                 line=3,
                 args=(
@@ -461,12 +562,10 @@ class TestSpellingChecker(CheckerTestCase):
     @set_config(spelling_dict=spell_dict)
     def test_docstring_lines_that_look_like_comments_4(self):
         stmt = astroid.extract_node(
-            # fmt: off
-            'def f():\n'
-            '    """\n'
-            '    # cat\n'
-            '    """'
-            # fmt: on
+            '''def f():
+    """
+    # cat
+    """'''
         )
         with self.assertAddsMessages():
             self.checker.visit_functiondef(stmt)
@@ -475,15 +574,13 @@ class TestSpellingChecker(CheckerTestCase):
     @set_config(spelling_dict=spell_dict)
     def test_docstring_lines_that_look_like_comments_5(self):
         stmt = astroid.extract_node(
-            # fmt: off
-            'def f():\n'
-            '    """\n'
-            '    msitake # cat\n'
-            '    """'
-            # fmt: on
+            '''def f():
+    """
+    msitake # cat
+    """'''
         )
         with self.assertAddsMessages(
-            Message(
+            MessageTest(
                 "wrong-spelling-in-docstring",
                 line=3,
                 args=(
@@ -500,15 +597,13 @@ class TestSpellingChecker(CheckerTestCase):
     @set_config(spelling_dict=spell_dict)
     def test_docstring_lines_that_look_like_comments_6(self):
         stmt = astroid.extract_node(
-            # fmt: off
-            'def f():\n'
-            '    """\n'
-            '    cat # msitake\n'
-            '    """'
-            # fmt: on
+            '''def f():
+    """
+    cat # msitake
+    """'''
         )
         with self.assertAddsMessages(
-            Message(
+            MessageTest(
                 "wrong-spelling-in-docstring",
                 line=3,
                 args=(
