@@ -1,4 +1,4 @@
-# pylint: disable=R0903,W0232, useless-object-inheritance
+# pylint: disable=too-few-public-methods,no-init, useless-object-inheritance
 """check for scope problems"""
 
 __revision__ = None
@@ -21,3 +21,23 @@ class Well(object):
     def func(self):
         """check Sub is not defined here"""
         return Sub(), self # [undefined-variable]
+
+
+class Right:
+    """right"""
+    class Result1:
+        """result one"""
+        OK = 0
+    def work(self) -> Result1:
+        """good type hint"""
+        return self.Result1.OK
+
+
+class Wrong:
+    """wrong"""
+    class Result2:
+        """result two"""
+        OK = 0
+    def work(self) -> self.Result2: # [undefined-variable]
+        """bad type hint"""
+        return self.Result2.OK
