@@ -1,7 +1,7 @@
 """Test the generated-members config option."""
 # pylint: disable=pointless-statement, invalid-name, useless-object-inheritance
 from __future__ import print_function
-from astroid import node_classes
+from astroid import nodes
 from pylint import checkers
 
 class Klass(object):
@@ -11,7 +11,7 @@ print(Klass().DoesNotExist)
 print(Klass().aBC_set1)
 print(Klass().ham.does.not_.exist)
 print(Klass().spam.does.not_.exist)  # [no-member]
-node_classes.Tuple.does.not_.exist
+nodes.Tuple.does.not_.exist
 checkers.base.doesnotexist()
 
 session = Klass()
