@@ -1,4 +1,5 @@
 from pylint.checkers import BaseChecker
+from pylint.lint.pylinter import PyLinter
 
 
 class DummyPlugin1(BaseChecker):
@@ -25,6 +26,6 @@ class DummyPlugin2(BaseChecker):
     )
 
 
-def register(linter):
+def register(linter: PyLinter) -> None:
     linter.register_checker(DummyPlugin1(linter))
     linter.register_checker(DummyPlugin2(linter))
