@@ -15,28 +15,34 @@
 # Copyright (c) 2020 Damien Baty <damien.baty@polyconseil.fr>
 # Copyright (c) 2020 Anthony Sottile <asottile@umich.edu>
 # Copyright (c) 2020 bernie gray <bfgray3@users.noreply.github.com>
+# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
+# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
+# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
 
 """Functional full-module tests for PyLint."""
 import csv
 import os
 import sys
+from typing import Union
 
 import pytest
+from _pytest.config import Config
+from _pytest.recwarn import WarningsRecorder
 
 from pylint import testutils
 from pylint.testutils import UPDATE_FILE, UPDATE_OPTION
+from pylint.testutils.functional_test_file import FunctionalTestFile
 from pylint.utils import HAS_ISORT_5
 
-# Notes:
-# - for the purpose of this test, the confidence levels HIGH and UNDEFINED
-#   are treated as the same.
-
 # TODOs
 #  - implement exhaustivity tests
 
+# 'Wet finger' number of files that are reasonable to display by an IDE
+# 'Wet finger' as in 'in my settings there are precisely this many'.
+REASONABLY_DISPLAYABLE_VERTICALLY = 48
+
 
 class LintModuleOutputUpdate(testutils.LintModuleTest):
     """If message files should be updated instead of checked."""
@@ -47,15 +53,12 @@ class LintModuleOutputUpdate(testutils.LintModuleTest):
 
     csv.register_dialect("test", TestDialect)
 
-    def _get_expected(self):
-        with self._open_source_file() as f:
-            expected_msgs = self.get_expected_messages(f)
-        return expected_msgs, []
-
     def _check_output_text(self, _, expected_output, actual_output):
-        if expected_output == actual_output:
+        if not expected_output and not actual_output:
+            if os.path.exists(self._test_file.expected_output):
+                os.remove(self._test_file.expected_output)
             return
-        with open(self._test_file.expected_output, "w") as f:
+        with open(self._test_file.expected_output, "w", encoding="utf-8") as f:
             writer = csv.writer(f, dialect="test")
             for line in actual_output:
                 writer.writerow(line.to_csv())
@@ -67,6 +70,11 @@ def get_tests():
     for dirpath, _, filenames in os.walk(input_dir):
         if dirpath.endswith("__pycache__"):
             continue
+
+        assert (
+            len(filenames) <= REASONABLY_DISPLAYABLE_VERTICALLY
+        ), f"{dirpath} contain too much functional tests files."
+
         for filename in filenames:
             if filename != "__init__.py" and filename.endswith(".py"):
                 # isort 5 has slightly different rules as isort 4. Testing
@@ -86,13 +94,18 @@ TEST_WITH_EXPECTED_DEPRECATION = [
 
 
 @pytest.mark.parametrize("test_file", TESTS, ids=TESTS_NAMES)
-def test_functional(test_file, recwarn):
+def test_functional(
+    test_file: FunctionalTestFile, recwarn: WarningsRecorder, pytestconfig: Config
+) -> None:
+    __tracebackhide__ = True  # pylint: disable=unused-variable
     if UPDATE_FILE.exists():
-        lint_test = LintModuleOutputUpdate(test_file)
+        lint_test: Union[
+            LintModuleOutputUpdate, testutils.LintModuleTest
+        ] = LintModuleOutputUpdate(test_file, pytestconfig)
     else:
-        lint_test = testutils.LintModuleTest(test_file)
+        lint_test = testutils.LintModuleTest(test_file, pytestconfig)
     lint_test.setUp()
-    lint_test._runTest()
+    lint_test.runTest()
     warning = None
     try:
         # Catch <unknown>:x: DeprecationWarning: invalid escape sequence
