@@ -10,15 +10,21 @@
 # Copyright (c) 2020 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2020 Damien Baty <damien.baty@polyconseil.fr>
 # Copyright (c) 2020 Frank Harrison <frank@doublethefish.com>
+# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
+# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
+# Copyright (c) 2021 Andrew Howe <howeaj@users.noreply.github.com>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
+# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
 # pylint: disable=redefined-outer-name
 
 import os
+import shutil
 from os.path import exists
+from typing import Iterator, Union
 
 import pytest
+from _pytest.fixtures import SubRequest
 
 from pylint import testutils
 from pylint.checkers import imports, initialize
@@ -26,8 +32,8 @@ from pylint.lint import PyLinter
 
 
 @pytest.fixture
-def dest():
-    dest = "dependencies_graph.dot"
+def dest(request: SubRequest) -> Iterator[Union[Iterator, Iterator[str]]]:
+    dest = request.param
     yield dest
     try:
         os.remove(dest)
@@ -36,13 +42,18 @@ def dest():
         pass
 
 
-def test_dependencies_graph(dest):
-    imports._dependencies_graph(dest, {"labas": ["hoho", "yep"], "hoho": ["yep"]})
-    with open(dest) as stream:
+POSSIBLE_DOT_FILENAMES = ["foo.dot", "foo.gv", "tests/regrtest_data/foo.dot"]
+
+
+@pytest.mark.parametrize("dest", POSSIBLE_DOT_FILENAMES, indirect=True)
+def test_dependencies_graph(dest: str) -> None:
+    """DOC files are correctly generated, and the graphname is the basename"""
+    imports._dependencies_graph(dest, {"labas": {"hoho", "yep"}, "hoho": {"yep"}})
+    with open(dest, encoding="utf-8") as stream:
         assert (
             stream.read().strip()
             == """
-digraph "dependencies_graph" {
+digraph "foo" {
 rankdir=LR
 charset="utf-8"
 URL="." node[shape="box"]
@@ -57,15 +68,25 @@ URL="." node[shape="box"]
         )
 
 
+@pytest.mark.parametrize("filename", ["graph.png", "graph"])
+@pytest.mark.skipif(
+    any(shutil.which(x) for x in ("dot", "gv")), reason="dot or gv is installed"
+)
+def test_missing_graphviz(filename: str) -> None:
+    """Raises if graphviz is not installed, and defaults to png if no extension given"""
+    with pytest.raises(RuntimeError, match=r"Cannot generate `graph\.png`.*"):
+        imports._dependencies_graph(filename, {"a": {"b", "c"}, "b": {"c"}})
+
+
 @pytest.fixture
-def linter():
+def linter() -> PyLinter:
     pylinter = PyLinter(reporter=testutils.GenericTestReporter())
     initialize(pylinter)
     return pylinter
 
 
 @pytest.fixture
-def remove_files():
+def remove_files() -> Iterator:
     yield
     for fname in ("import.dot", "ext_import.dot", "int_import.dot"):
         try:
@@ -75,7 +96,7 @@ def remove_files():
 
 
 @pytest.mark.usefixtures("remove_files")
-def test_checker_dep_graphs(linter):
+def test_checker_dep_graphs(linter: PyLinter) -> None:
     linter.global_set_option("persistent", False)
     linter.global_set_option("reports", True)
     linter.global_set_option("enable", "imports")
@@ -85,7 +106,7 @@ def test_checker_dep_graphs(linter):
     linter.global_set_option("int-import-graph", "int_import.dot")
     # ignore this file causing spurious MemoryError w/ some python version (>=2.3?)
     linter.global_set_option("ignore", ("func_unknown_encoding.py",))
-    linter.check("input")
+    linter.check(["input"])
     linter.generate_reports()
     assert exists("import.dot")
     assert exists("ext_import.dot")
